import 'package:flutter/material.dart';
import 'dart:async';
import 'dart:typed_data';
import 'package:flutter/services.dart';
import 'package:wmc_personalized_plugin/wmc_personalized_plugin.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _result = 'Unknown';

  @override
  void initState() {
    super.initState();
    /*
     Haber solicitado permiso de READ_PHONE_STATE para el caso de 
     Android ya que por default se envia el codigo de identificador en null en 
     ios no es necesario
     */
    initializeWmc();
    sendRequest();
    //sendPost();
    //sendPut();
    //sendResource();
    //getConnectionData();
  }

  Future<void> initializeWmc() async {
    String initializeWmc; 
    try {
      initializeWmc = await WmcPersonalizedPlugin.initialize("36f4de87aca77d091a54f388fcfb9a6e");
    } on PlatformException {
      initializeWmc = 'Failed to initialize WMC.';
    }

    setState(() {
      _result = initializeWmc;
    });
  }

  Future<void> sendRequest() async{ 
    Map result;  
    try {
      result = await WmcPersonalizedPlugin.request(
         "http://dummy.restapiexample.com/api/v1/employees",
        "GET",
        { 'content-type': 'application/json' },
        {'abc': '123'},
      );
    } on PlatformException {
      print("Ocurrió un error");
    } catch (e) {
      print("Llegó a este error: ${e.toString()}");
    }
 
    print(result);
    setState(() {
      _result = result.toString();
    }); 
  }


  Future<void> sendPost() async{ 
    Map result;  
    try {
      result = await WmcPersonalizedPlugin.post(
        "http://dummy.restapiexample.com/api/v1/create",  
        { 'content-type': 'application/json' },
        "{\"name\":\"test\",\"salary\":\"123\",\"age\":\"23\"}",
      );
    } on PlatformException {
      print("Ocurrió un error");
    } catch (e) {
      print("Llegó a este error: ${e.toString()}");
    }
 
    print(result);
    setState(() {
      _result = result.toString();
    }); 
  }

  Future<void> sendPut() async{ 
    Map result;  
    try {
      result = await WmcPersonalizedPlugin.put(
        "http://dummy.restapiexample.com/api/v1/update/719", 
        { 'content-type': 'application/json' },
        "{\"name\":\"test1\",\"salary\":\"1123\",\"age\":\"23\"}",
      );
    } on PlatformException {
      print("Ocurrió un error");
    } catch (e) {
      print("Llegó a este error: ${e.toString()}");
    }
 
    print(result);
    setState(() {
      _result = result.toString();
    }); 
  }


  Future<void> getConnectionData() async{ 
    Map result;  
    try {
      result = await WmcPersonalizedPlugin.getConnectionData();
    } on PlatformException {
      print("Ocurrió un error");
    } catch (e) {
      print("Llegó a este error: ${e.toString()}");
    }
 
    print(result);
    setState(() {
      _result = result.toString();
    }); 
  }

  Future<void> sendResource() async{ 
    Uint8List result;  

    try { 
        result = await WmcPersonalizedPlugin.resource("https://worldmobileconnection.com/wp-content/uploads/2018/03/LOGO-WORLD-MOBILE.png");
    } on PlatformException { 

    } 
    setState(() {
      _result = result.toString();
    }); 
  }


  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Text('Running on: $_result\n'),
        ),
      ),
    );
  }
}
